"use strict";
/**
 * @fileoverview Component property should be set
 * @author Yann Braga
 */
const constants_1 = require("../utils/constants");
const create_storybook_rule_1 = require("../utils/create-storybook-rule");
module.exports = (0, create_storybook_rule_1.createStorybookRule)({
    name: '',
    defaultOptions: [],
    meta: {
        type: 'suggestion',
        docs: {
            description: 'The component property should be set',
            categories: [constants_1.CategoryId.CSF],
            recommended: 'warn',
        },
        messages: {
            missingComponentProperty: 'Missing component property.',
        },
        schema: [],
    },
    create(context) {
        // variables should be defined here
        //----------------------------------------------------------------------
        // Helpers
        //----------------------------------------------------------------------
        // any helper functions should go here or else delete this section
        //----------------------------------------------------------------------
        // Public
        //----------------------------------------------------------------------
        return {
            ExportDefaultDeclaration: function (node) {
                // Typescript 'TSAsExpression' has properties under declaration.expression
                const metaProperties = node.declaration.properties ||
                    (node.declaration.expression && node.declaration.expression.properties);
                if (!metaProperties) {
                    return;
                }
                const component = metaProperties.find((prop) => prop.key.name === 'component');
                if (!component) {
                    context.report({
                        node,
                        messageId: 'missingComponentProperty',
                    });
                }
            },
        };
    },
});
