"use strict";
/**
 * @fileoverview Deprecated hierarchy separator
 * @author Yann Braga
 */
const constants_1 = require("../utils/constants");
const create_storybook_rule_1 = require("../utils/create-storybook-rule");
module.exports = (0, create_storybook_rule_1.createStorybookRule)({
    name: '',
    defaultOptions: [],
    meta: {
        type: 'problem',
        fixable: 'code',
        docs: {
            description: 'Deprecated hierachy separator in title property',
            categories: [constants_1.CategoryId.CSF, constants_1.CategoryId.RECOMMENDED],
            recommended: 'warn',
        },
        messages: {
            useCorrectSeparators: 'Use correct separators',
            deprecatedHierarchySeparator: 'Deprecated hierachy separator in title property: {{metaTitle}}.',
        },
        schema: [],
    },
    create: function (context) {
        return {
            ExportDefaultDeclaration: function (node) {
                // Typescript 'TSAsExpression' has properties under declaration.expression
                const metaProperties = node.declaration.properties ||
                    (node.declaration.expression && node.declaration.expression.properties);
                if (!metaProperties) {
                    return;
                }
                const titleNode = metaProperties.find((prop) => prop.key.name === 'title');
                // @ts-expect-error ts-migrate(2367) FIXME: This condition will always return 'false' since th... Remove this comment to see the full error message
                if (!titleNode || !titleNode.value.type === 'Literal') {
                    return;
                }
                const metaTitle = titleNode.value.raw || '';
                if (metaTitle.includes('|') || metaTitle.includes('.')) {
                    context.report({
                        node,
                        messageId: 'deprecatedHierarchySeparator',
                        data: { metaTitle },
                        // In case we want this to be auto fixed by --fix
                        fix: function (fixer) {
                            return fixer.replaceTextRange(titleNode.value.range, metaTitle.replace(/\||\./g, '/'));
                        },
                        suggest: [
                            {
                                messageId: 'useCorrectSeparators',
                                fix: function (fixer) {
                                    return fixer.replaceTextRange(titleNode.value.range, metaTitle.replace(/\||\./g, '/'));
                                },
                            },
                        ],
                    });
                }
            },
        };
    },
});
